summaryrefslogtreecommitdiffstats
path: root/build_tools/bin/mp.py
diff options
context:
space:
mode:
Diffstat (limited to 'build_tools/bin/mp.py')
-rwxr-xr-xbuild_tools/bin/mp.py6
1 files changed, 5 insertions, 1 deletions
diff --git a/build_tools/bin/mp.py b/build_tools/bin/mp.py
index 77f73c8..068b089 100755
--- a/build_tools/bin/mp.py
+++ b/build_tools/bin/mp.py
@@ -138,9 +138,13 @@ def commandline():
makepkg_cmd.extend(cli_list)
makepkg_cmd.extend(final_dict)
# Remove bump option if it exists
if "--bump" in makepkg_cmd:
makepkg_cmd.remove("--bump")
+ # Remove --geninteg option (if it exists) from makepkg command.
+ # Checking for *sums is done automaticly by mp.py
+ if "--geninteg" in makepkg_cmd:
+ makepkg_cmd.remove("--geninteg")
print "Makepkg Command:",makepkg_cmd
def bump_pkg():
@@ -138,9 +138,13 @@ def commandline():
makepkg_cmd.extend(cli_list)
makepkg_cmd.extend(final_dict)
- # Remove bump option if it exists
+ # Remove bump option from makepkg command if it exists
if "--bump" in makepkg_cmd:
makepkg_cmd.remove("--bump")